@@ -235,16 +235,32 @@ class CIFMixin:
         ys = []
         zs = []
         symbols = []
+        # May have type symbols or labels, or both. Use type symbols by preference
+        if "_atom_site_type_symbol" in data_block:
+            type_section = "_atom_site_type_symbol"
+        elif "_atom_site_label" in data_block:
+            type_section = "_atom_site_label"
+        else:
+            raise KeyError(
+                "Neither _atom_site_type_label or _atom_site_label are in file"
+            )
         for x, y, z, symbol in zip(
             data_block["_atom_site_fract_x"],
             data_block["_atom_site_fract_y"],
             data_block["_atom_site_fract_z"],
-            data_block["_atom_site_type_symbol"],
+            data_block[type_section],
         ):  # yapf: disable
+            # Atom symbols may be followed by number, etc.
+            if len(symbol) > 1:
+                if symbol[1].isalpha():
+                    symbol = symbol[0:2]
+                else:
+                    symbol = symbol[0]
             # These variables *are* used in the eval below.
             x = float(x)
             y = float(y)
             z = float(z)
+            logger.debug(f"xyz = {x:7.3f} {y:7.3f} {z:7.3f}")
             for symop in data_block[symdata]:
                 x_eq, y_eq, z_eq = symop.split(",")
                 x_new = eval(x_eq)
@@ -262,6 +278,7 @@ class CIFMixin:
                 if abs(1 - z_new) < delta:
                     z_new = 0.0
                 found = False
+                logger.debug(f"-->   {x_new:7.3f} {y_new:7.3f} {z_new:7.3f}")
                 for x0, y0, z0 in zip(xs, ys, zs):
                     if (
                         abs(x_new - x0) < delta
@@ -269,6 +286,7 @@ class CIFMixin:
                         and abs(z_new - z0) < delta
                     ):
                         found = True
+                        logger.debug("         found!")
                         break
                 if not found:
                     xs.append(x_new)
@@ -277,6 +295,9 @@ class CIFMixin:
                     symbols.append(symbol)
         self.atoms.append(x=xs, y=ys, z=zs, symbol=symbols)
 
+        # Find the symmetry and set to the conventional cell.
+        self.symmetrize(symprec=0.0001)
+
     def to_mmcif_text(self):
         """Create the text of a mmCIF file from this configuration.
 
